@@ -217,7 +217,7 @@ void YouTube::checkYouTubeVideoInfoPage() {
 }
 
 void YouTube::getYouTubeVideoWebPage(const QString &id) {
-    QUrl url("http://www.youtube.com/watch");
+    QUrl url("https://www.youtube.com/watch");
 #if QT_VERSION >= 0x050000
     QUrlQuery query;
     query.addQueryItem("v", id);
@@ -232,7 +232,7 @@ void YouTube::getYouTubeVideoWebPage(const QString &id) {
     url.addQueryItem("has_verified", "1");
 #endif
     QNetworkRequest request(url);
-    request.setRawHeader("User-Agent", "Mozilla/5.0 (X11; Linux x86_64; rv:28.0) Gecko/20100101  Firefox/28.0");
+    request.setRawHeader("User-Agent", "Wget/1.13.4 (linux-gnu)");
     QNetworkReply *reply = this->networkAccessManager()->get(request);
     this->connect(reply, SIGNAL(finished()), this, SLOT(checkYouTubeWebPage()));
     this->connect(this, SIGNAL(currentOperationCancelled()), reply, SLOT(deleteLater()));
@@ -247,19 +247,19 @@ void YouTube::checkYouTubeWebPage() {
     }
 
     QString response(reply->readAll());
-
+	
     if (!response.contains("url_encoded_fmt_stream_map\":")) {
         emit error(UnknownError);
     }
     else {
-        QVariantMap assets = Json::parse(QString("%1}").arg(response.section("\"assets\": ", 1, 1).section('}', 0, 0))).toMap();
+        QVariantMap assets = Json::parse(QString("%1}").arg(response.section("\"assets\":", 1, 1).section('}', 0, 0))).toMap();
         QUrl playerUrl = assets.value("js").toUrl();
 
         if (playerUrl.scheme().isEmpty()) {
             playerUrl.setScheme("http");
         }
 
-        response = response.section("url_encoded_fmt_stream_map\": \"", 1, 1).section(", \"", 0, 0).trimmed().replace("\\u0026", "&").remove(QRegExp("itag=\\d+"));
+        response = response.section("url_encoded_fmt_stream_map\":\"", 1, 1).section(",\"", 0, 0).trimmed().replace("\\u0026", "&").remove(QRegExp("itag=\\d+"));
 
         bool encryptedSignatures = !response.contains("sig=");
 
@@ -316,7 +316,7 @@ QScriptValue YouTube::getYouTubeDecryptionFunction(const QUrl &playerUrl) {
     if (decryptionCache.contains(playerUrl)) {
         return decryptionCache.value(playerUrl);
     }
-
+	
     QNetworkRequest request(playerUrl);
     QNetworkReply *reply = this->networkAccessManager()->get(request);
     this->connect(reply, SIGNAL(finished()), this, SLOT(addYouTubeDecryptionFunctionToCache()));
